@@ -4,7 +4,7 @@ def dropbox_upload_file(src_file_path, destination_path, ACCESS_TOKEN):
     destination_path = destination_path.replace('\\', '/')
     src_file_path = src_file_path.replace('\\', '/')
     if destination_path[-1] == '/':
-        del destination_path[-1]
+        destination_path = destination_path[:-1]
     if '.' not in destination_path.split('/')[-1]:
         destination_path += "/" + src_file_path.split('/')[-1]
     with open(src_file_path, "rb") as f:
@@ -15,10 +15,10 @@ def dropbox_upload_folder(folder_path, destination_path, ACCESS_TOKEN):
     import glob
     folder_path = folder_path.replace('\\', '/')
     if folder_path[-1] == '/':
-        del folder_path[-1]
+        folder_path = folder_path[:-1]
     destination_path = destination_path.replace('\\', '/')
     if destination_path[-1] == '/':
-        del destination_path[-1]
+        destination_path = destination_path[:-1]
     file_list = glob.glob(f'{folder_path}/**')
     for file_path in file_list:
         filename = file_path.split('\\')[-1]
